@@ -202,7 +202,7 @@ int ContentDirectory::readDirSlice(
         return UPNP_E_BAD_RESPONSE;
     }
 
-    LOGDEB0("ContentDirectory::readDirSlice: got count " << count <<
+    LOGDEB0("ContentDirectory::readDirSlice: got count " << *didread <<
             " offset " << offset << " total " << *total << " Data:\n" << tbuf << "\n");
 
     dirbuf.parse(tbuf);
