@@ -1,4 +1,4 @@
-/* Copyright (C) 2006-2016 J.F.Dockes
+/* Copyright (C) 2006-2024 J.F.Dockes
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,13 +15,13 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  *   02110-1301 USA
  */
-#include "libupnpp/config.h"
+#include "config.h"
 
 #include "libupnpp/control/ohsender.hxx"
 #include "libupnpp/control/cdircontent.hxx"
 
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <upnp.h>
 
 #include <functional>
@@ -56,31 +56,26 @@ bool OHSender::serviceTypeMatch(const std::string& tp)
     return isOHSenderService(tp);
 }
 
-void OHSender::evtCallback(
-    const std::unordered_map<std::string, std::string>& props)
+void OHSender::evtCallback(const std::unordered_map<std::string, std::string>& props)
 {
-    LOGDEB1("OHSender::evtCallback:getReporter(): " << getReporter() << endl);
-    for (std::unordered_map<std::string, std::string>::const_iterator it =
-                props.begin(); it != props.end(); it++) {
+    LOGDEB1("OHSender::evtCallback:getReporter(): " << getReporter() << '\n');
+    for (const auto& [propname, propvalue] : props) {
         if (!getReporter()) {
-            LOGDEB1("OHSender::evtCallback: " << it->first << " -> "
-                    << it->second << endl);
+            LOGDEB1("OHSender::evtCallback: " << propname << " -> " << propvalue << '\n');
             continue;
         }
 
-        if (!it->first.compare("Audio")) {
+        if (propname == "Audio") {
             bool val = false;
-            stringToBool(it->second, &val);
-            getReporter()->changed(it->first.c_str(), val ? 1 : 0);
-        } else if (!it->first.compare("Metadata") ||
-                   !it->first.compare("Attributes") ||
-                   !it->first.compare("PresentationUrl") ||
-                   !it->first.compare("Status")) {
-            getReporter()->changed(it->first.c_str(), it->second.c_str());
+            stringToBool(propvalue, &val);
+            getReporter()->changed(propname.c_str(), val ? 1 : 0);
+        } else if (propname == "Metadata" || propname == "Attributes" ||
+                   propname == "PresentationUrl" || propname == "Status") {
+            getReporter()->changed(propname.c_str(), propvalue.c_str());
         } else {
             LOGERR("OHSender event: unknown variable: name [" <<
-                   it->first << "] value [" << it->second << endl);
-            getReporter()->changed(it->first.c_str(), it->second.c_str());
+                   propname << "] value [" << propvalue << '\n');
+            getReporter()->changed(propname.c_str(), propvalue.c_str());
         }
     }
 }
@@ -99,24 +94,23 @@ int OHSender::metadata(string& uri, string& didl)
         return ret;
     }
     if (!data.get("Value", &didl)) {
-        LOGERR("OHSender::Sender: missing Value in response" << endl);
+        LOGERR("OHSender::Sender: missing Value in response" << '\n');
         return UPNP_E_BAD_RESPONSE;
     }
 
     // Try to parse the metadata and extract the Uri.
     UPnPDirContent dir;
     if (!dir.parse(didl)) {
-        LOGERR("OHSender::Metadata: didl parse failed: " << didl << endl);
+        LOGERR("OHSender::Metadata: didl parse failed: " << didl << '\n');
         return UPNP_E_BAD_RESPONSE;
     }
     if (dir.m_items.size() != 1) {
-        LOGERR("OHSender::Metadata: " << dir.m_items.size() <<
-               " in response!" << endl);
+        LOGERR("OHSender::Metadata: " << dir.m_items.size() << " in response!" << '\n');
         return UPNP_E_BAD_RESPONSE;
     }
-    UPnPDirObject *dirent = &dir.m_items[0];
+    UPnPDirObject* dirent = dir.m_items.data();
     if (dirent->m_resources.size() < 1) {
-        LOGERR("OHSender::Metadata: no resources in metadata!" << endl);
+        LOGERR("OHSender::Metadata: no resources in metadata!" << '\n');
         return UPNP_E_BAD_RESPONSE;
     }
     uri = dirent->m_resources[0].m_uri;
