@@ -44,13 +44,11 @@ string upnpduration(int ms)
     int secs = ms / 1000;
     ms -= secs * 1000;
 
-    char cbuf[100];
-
-    // This is the format from the ref doc, but it appears that the
-    // decimal part in the seconds field is an issue with some control
-    // points. So drop it...
+    // The format from the ref doc has a fractional part in the seconds field, but it appears that
+    // this is an issue with some control points. So drop it...
     //  sprintf(cbuf, "%d:%02d:%02d.%03d", hours, minutes, secs, ms);
-    sprintf(cbuf, "%d:%02d:%02d", hours, minutes, secs);
+    char cbuf[100];
+    snprintf(cbuf, 100, "%d:%02d:%02d", hours, minutes, secs);
     return cbuf;
 }
 
