@@ -414,10 +414,10 @@ string LibUPnP::makeDevUUID(const std::string& name, const std::string& hw)
     std::remove_copy(hw.begin(), hw.end(), std::back_inserter(nhw), ':');
 
     char uuid[100];
-    sprintf(uuid, "%02x%02x%02x%02x-%02x%02x-%02x%02x-%02x%02x-%s",
-            digest[0]&0xff, digest[1]&0xff, digest[2]&0xff, digest[3]&0xff,
-            digest[4]&0xff, digest[5]&0xff,  digest[6]&0xff, digest[7]&0xff,
-            digest[8]&0xff, digest[9]&0xff, nhw.c_str());
+    snprintf(uuid, 100, "%02x%02x%02x%02x-%02x%02x-%02x%02x-%02x%02x-%s",
+             digest[0]&0xff, digest[1]&0xff, digest[2]&0xff, digest[3]&0xff,
+             digest[4]&0xff, digest[5]&0xff,  digest[6]&0xff, digest[7]&0xff,
+             digest[8]&0xff, digest[9]&0xff, nhw.c_str());
     return uuid;
 }
 
